==> huaweicloudsdkcodeartsgovernance-3.1.139-py2.py3-none-any.whl: huaweicloudsdkcodeartsgovernance/v1/model/hm_vuln_info_data_report.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class HmVulnInfoDataReport:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'detail': 'HmVulnInfoDataDetail',
        'file_name': 'str'
    }

    attribute_map = {
        'detail': 'detail',
        'file_name': 'file_name'
    }

    def __init__(self, detail=None, file_name=None):
        """HmVulnInfoDataReport

        The model defined in huaweicloud sdk

        :param detail: 
        :type detail: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoDataDetail`
        :param file_name: 文件名
        :type file_name: str
        """
        
        

        self._detail = None
        self._file_name = None
        self.discriminator = None

        if detail is not None:
            self.detail = detail
        if file_name is not None:
            self.file_name = file_name

    @property
    def detail(self):
        """Gets the detail of this HmVulnInfoDataReport.

        :return: The detail of this HmVulnInfoDataReport.
        :rtype: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoDataDetail`
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this HmVulnInfoDataReport.

        :param detail: The detail of this HmVulnInfoDataReport.
        :type detail: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoDataDetail`
        """
        self._detail = detail

    @property
    def file_name(self):
        """Gets the file_name of this HmVulnInfoDataReport.

        文件名

        :return: The file_name of this HmVulnInfoDataReport.
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this HmVulnInfoDataReport.

        文件名

        :param file_name: The file_name of this HmVulnInfoDataReport.
        :type file_name: str
        """
        self._file_name = file_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HmVulnInfoDataReport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodeartsgovernance-3.1.143-py2.py3-none-any.whl: huaweicloudsdkcodeartsgovernance/v1/model/hm_vuln_info_data_report.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class HmVulnInfoDataReport:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'detail': 'HmVulnInfoDataDetail',
        'file_name': 'str'
    }

    attribute_map = {
        'detail': 'detail',
        'file_name': 'file_name'
    }

    def __init__(self, detail=None, file_name=None):
        r"""HmVulnInfoDataReport

        The model defined in huaweicloud sdk

        :param detail: 
        :type detail: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoDataDetail`
        :param file_name: 文件名
        :type file_name: str
        """
        
        

        self._detail = None
        self._file_name = None
        self.discriminator = None

        if detail is not None:
            self.detail = detail
        if file_name is not None:
            self.file_name = file_name

    @property
    def detail(self):
        r"""Gets the detail of this HmVulnInfoDataReport.

        :return: The detail of this HmVulnInfoDataReport.
        :rtype: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoDataDetail`
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        r"""Sets the detail of this HmVulnInfoDataReport.

        :param detail: The detail of this HmVulnInfoDataReport.
        :type detail: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoDataDetail`
        """
        self._detail = detail

    @property
    def file_name(self):
        r"""Gets the file_name of this HmVulnInfoDataReport.

        文件名

        :return: The file_name of this HmVulnInfoDataReport.
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        r"""Sets the file_name of this HmVulnInfoDataReport.

        文件名

        :param file_name: The file_name of this HmVulnInfoDataReport.
        :type file_name: str
        """
        self._file_name = file_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HmVulnInfoDataReport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
